#!/bin/bash
# -*- coding: utf-8 -*-
#

##################################################

PROG="/root/cvs/web/bin/httpd-teng"
CONF="/root/cvs/web/conf/httpd.conf"
NICE=0
STOP_TIMEOUT=20

MAX_PROCESS=450
MAX_DATA_SEGM=50000
MAX_LOCK_MEM=30000
MAX_RESIDENT_MEM=50000
MAX_STACK=30000
MAX_VIRTUAL_MEM=100000


RANDOM_SLEEP=120

##################################################

NAME=`/usr/bin/basename ${PROG}`

#test if file exist
if [ ! -x ${PROG} -o ! -s ${CONF} ]
then
        [ -x ${PROG} ] || echo "${PROG} does not exist or is not executable"
        [ -s ${CONF} ] || echo "${CONF} does not exist or is empty"
        exit 1
fi

#test if ${PROG} is binary or symlink
if [ -h ${PROG} ]
then
        PIDOF_CMD="/bin/pidof ${NAME}"
else
        PIDOF_CMD="/bin/pidof ${PROG}"
fi


case "$1" in
        start)

                echo -n "Starting ${NAME}: "
                if [ "`${PIDOF_CMD}`" ]
                then
                        echo "failed. (${NAME} is running, pids: `${PIDOF_CMD}`)"
                        exit 1
                else

                        #set up ulimit
                        ulimit  -u $MAX_PROCESS      \
                                -d $MAX_DATA_SEGM    \
                                -l $MAX_LOCK_MEM     \
                                -m $MAX_RESIDENT_MEM \
                                -s $MAX_STACK        \
                                -v $MAX_VIRTUAL_MEM  \
                                -c unlimited 1>/dev/null 2>/dev/null

                        #start program
                        ${PROG} -f ${CONF}

                        #renice
                        /usr/bin/renice ${NICE} `${PIDOF_CMD}` 1>/dev/null 2>/dev/null

                        echo "done."
                        exit 0
                fi
                ;;

        stop)

                echo -n "Stopping ${NAME}: "
                if [ "`${PIDOF_CMD}`" ]
                then
                        #kill process
                        /bin/kill -TERM `${PIDOF_CMD}`

                        #wait until the timeout for processes to die.
                        COUNT=${STOP_TIMEOUT}
                        while ([ $COUNT != 0 ])
                        do
                                let COUNT=$COUNT-1
                                if [ "`${PIDOF_CMD}`" ]
                                then
                                        echo -n .
                                        /bin/sleep 1
                                else
                                        COUNT=0
                                fi
                        done

                        #if it's not dead yet, kill it.
                        if [ "`${PIDOF_CMD}`" ]
                        then
                                /bin/kill -KILL `${PIDOF_CMD}`
                                echo " done. (used KILL)"
                        else
                                echo " done."
                        fi

                else
                        echo "failed. (${NAME} is not running)"
                fi

                ;;

        restart)
                ${0} stop
                /bin/sleep 1
                ${0} start
                ;;

        reload)
                echo -n "Reloading ${NAME}: "
                if [ "`${PIDOF_CMD}`" ]
                then
                        /bin/kill -USR1 `${PIDOF_CMD}`
                        echo " done."
                        exit 0
                else
                        echo "failed. (${NAME} is not running)"
                        exit 1
                fi
                ;;

        status)

                if [ "`${PIDOF_CMD}`" ]
                then
                        echo "${NAME} is running, pids: `${PIDOF_CMD}`"
                        exit 1

                else
                        echo "${NAME} is not running"
                fi
                ;;

        *)
                echo "Usage: ${0} {start|stop|reload|restart}"
                ;;
esac

exit 0
